aboutsummaryrefslogtreecommitdiffstats
path: root/src/mds.c
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mds.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mds.c b/src/mds.c
index 36d3465..cc6adfd 100644
--- a/src/mds.c
+++ b/src/mds.c
@@ -99,8 +99,8 @@ int main(int argc_, char** argv_)
exit_if (geteuid() != ROOT_USER_UID,
eprint("the effective user is not root, cannot continue."););
- /* Set up to ignore SIGUSR1, used in mds for re-exec, but we cannot re-exec. */
- if (xsigaction(SIGUSR1, SIG_IGN) < 0)
+ /* Set up to ignore SIGUPDATE, used in mds for re-exec, but we cannot re-exec. */
+ if (xsigaction(SIGUPDATE, SIG_IGN) < 0)
perror(*argv);
/* Set up to ignore SIGDANGER. */